<?php
/*
 * Plugin Name: MobiPay24 Integration
 * Plugin URI: https://mobipay24.com
 * Description: Accept Mobipay24 payments on your store.
 * Author: MobiPay24
 * Author URI: https://mobipay24.com
 * Version: 1.0
 *
/*
 * This action hook registers our PHP class as a WooCommerce payment gateway
 */
if (!defined('ABSPATH')) {
    exit;
}



if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))){
    echo "<div class='error notice'><p>Woocommerce has to be installed and active to use the the MobiPay24 Payments Gateway</b> plugin</p></div>";
    return;
}


add_action( 'init', 'my_url_handler' );

function my_url_handler() {
    if(strpos($_SERVER["REQUEST_URI"], '/wc-api/phpwallet-payment-complete') !== false ) {

        

        if( isset( $_GET['token']) &&  isset( $_GET['id'] ) ) {
            global $woocommerce;
            

            $gateway_wc_phpwallet = new WC_phpwallet_Gateway();

            $post = array(
            'merchant_key'=> $gateway_wc_phpwallet->merchant_key,
            'token'=> $_GET['token']
            );


            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $gateway_wc_phpwallet->merchant_request_status_url);
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $post);

            $response = json_decode(curl_exec($ch),true);

            curl_close($ch);

            if ($response['status'] == true) {
                    
                if ($response['data']['entity_id'] == $gateway_wc_phpwallet->merchant_id) {
                    
                    $myaccount_page_id = get_option( 'woocommerce_myaccount_page_id' );

                    if ( $myaccount_page_id ) {

                      $myaccount_page_url = get_permalink( $myaccount_page_id );
                    
                    }
                    
                    $order = wc_get_order( $_GET['id'] );
                    $order->payment_complete();
                    $order->reduce_order_stock();
                    wp_redirect( $myaccount_page_url ) ;

                    exit();
                    
                }else{
                    echo 'invalid_merchant_id';
                }  
            }else{
                echo "woops, something went wrong";
            }
        }
    }
}

add_filter( 'woocommerce_payment_gateways', 'phpwallet_add_gateway_class' );
function phpwallet_add_gateway_class( $gateways ) {
    $gateways[] = 'WC_phpwallet_Gateway'; // your class name is here
    return $gateways;
}
 
function phpwallet_init_gateway_class() {
 
    class WC_phpwallet_Gateway extends WC_Payment_Gateway {
 
        /**
         * Class constructor, more about it in Step 3
         */
        public function __construct() {

            
      
            
            
            $this->id = 'phpwallet_gateway'; // payment gateway plugin ID
            $this->icon = ''; // URL of the icon that will be displayed on checkout page near your gateway name
            $this->has_fields = false; // in case you need a custom credit card form
            $this->method_title = 'MobiPay24';
            $this->method_description = 'Accept payments online with MobiPay24 payment gateway'; // will be displayed on the options page
         
            // gateways can support subscriptions, refunds, saved payment methods,
            // but in this tutorial we begin with simple payments
            $this->supports = array(
                'products'
            );
         
            // Method with all the options fields
            $this->init_form_fields();
         
            // Load the settings.
            $this->init_settings();
            $this->title = "MobiPay24";
            $this->merchant_key = $this->get_option( 'merchant_key' );
            $this->enabled = $this->get_option( 'enabled' );
            $this->merchant_currency_code =  $this->get_option( 'merchant_currency_code' );
            $this->merchant_request_url =  $this->get_option( 'merchant_request_url' );
            $this->merchant_request_status_url =  $this->get_option( 'merchant_request_status_url' );
            $this->merchant_id =  $this->get_option( 'merchant_id' );
           
         
            // This action hook saves the settings
            add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
         
            // We need custom JavaScript to obtain a token
            add_action( 'wp_enqueue_scripts', array( $this, 'payment_scripts' ) );
         
           
            //add_action( 'woocommerce_api_phpwallet-payment-complete', array( $this, 'payment_update' ) );
 
        }
 
        /**
         * Plugin options, we deal with it in Step 3 too
         */
        public function init_form_fields(){
 
            $this->form_fields = array(
                'enabled' => array(
                    'title'       => 'Enable/Disable',
                    'label'       => 'Enable MobiPay24 Gateway',
                    'type'        => 'checkbox',
                    'description' => '',
                    'default'     => 'no'
                ),
                'title' => array(
                    'title'       => 'Title',
                    'type'        => 'text',
                    'description' => 'This controls the title which the user sees during checkout.',
                    'default'     => 'MobiPay24',
                    'desc_tip'    => true,
                ),
                'merchant_request_url' => array(
                    'title'       => 'Merchant request (URL)',
                    'type'        => 'text',
                    'default'     => '',
                ),
                'merchant_request_status_url' => array(
                    'title'       => 'Merchant transaction status (URL)',
                    'type'        => 'text',
                    'default'     => '',
                ),
                'merchant_key' => array(
                    'title'       => 'Merchant Key',
                    'type'        => 'text',
                    'default'     => '',
                ),
                'merchant_currency_code' => array(
                    'title'       => 'Merchant Currency Code',
                    'type'        => 'text'
                ),
                'merchant_id' => array(
                    'title'       => 'Merchant ID',
                    'type'        => 'text',
                ),
            );
        }
 
        /**
         * You will need it if you want your custom credit card form, Step 4 is about it
         */
        // public function payment_fields() {
 
        
 
        // }
 
        /*
         * Custom CSS and JS, in most cases required only when you decided to go with a custom credit card form
         */
        public function payment_scripts() {
 
        
 
        }
 
        /*
         * Fields validation, more in Step 5
         */
        // public function validate_fields() {
 
        
 
        // }
 
        /*
         * We're processing the payments here, everything about it is in Step 5
         */
        public function process_payment( $order_id ) {
            
            global $woocommerce;
 
            // we need it to get any order detailes
            $order = wc_get_order( $order_id );

            if (isset($GET['token'])) {
                var_dump($GET['token']);
                return;
            }

            /*
             * Array with parameters for API interaction
             */
            $items = array();

            $order_items = $order->get_items(array('line_item', 'fee', 'shipping'));

            if ( !is_wp_error( $order_items ) ) {
                foreach( $order_items as $item_id => $order_item ) {
                    //echo $order_item->get_order_id();
                    //echo $order_item->get_name();
                    //echo $order_item->get_total(); // item price
                    //echo $order_item->get_type(); // line_item | fee | shipping
             
                    // for products only:
                    //echo $order_item->get_quantity(); // or $order_item['quantity'];
                    //echo $order_item->get_product_id(); // or $order_item['product_id'];
                    //echo $order_item->get_variation_id(); // or $order_item['variation_id'];
                    //echo $order_item->get_product(); // get the associated product

                    $item['name'] = $order_item->get_name();
                    $item['price']  = $order_item->get_total()/$order_item->get_quantity(); 
                    $item['qty']    =   $order_item->get_quantity();
                    $item['description']    =  $order_item->get_name();
                    
                    array_push($items, $item);
                }
            }
            
            $data['items'] = $items;    
            $data['invoice_id'] = $order_id;
            $data['invoice_description'] = "Order with Invoice ".  $order_id ;
            $data['total'] = $order->get_total();
            $data['return_url'] = get_option('siteurl').'/wc-api/phpwallet-payment-complete?id='.$order_id;
            $data['cancel_url'] = get_option('siteurl');
            $encodeddata = json_encode($data);

            $post = array(
                'merchant_key'=> $this->merchant_key,
                'invoice'=> $encodeddata,
                'currency_code' =>  $this->merchant_currency_code
            );

         

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $this->merchant_request_url );
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $post);

            $response = json_decode(curl_exec($ch),true);

            curl_close($ch);

            $order->update_status('on-hold: awaiting payment', 'Awaiting payment');
            $woocommerce->cart->empty_cart();

            return array(
               'result' => 'success',
               'redirect' => $response['link']
            ); 

        }
 
        /*
         * In case you need a webhook, like PayPal IPN etc
         */
        public function payment_update() {
            // $order = wc_get_order( $_GET['id'] );
            // $order->payment_complete();
            // $order->reduce_order_stock();
         
            // update_option('webhook_debug', $_GET);  
        }
    }
}


/*
 * The class itself, please note that it is inside plugins_loaded action hook
 */
add_action( 'plugins_loaded', 'phpwallet_init_gateway_class' );
